Welcome to genno's documentation!
*********************************

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api
   compat
   whatsnew
   releasing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
